@@ -4,9 +4,9 @@ Main interface for comprehend service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_comprehend.type_defs import BatchDetectDominantLanguageItemResultTypeDef
+    from mypy_boto3_comprehend.type_defs import AugmentedManifestsListItemTypeDef
 
-    data: BatchDetectDominantLanguageItemResultTypeDef = {...}
+    data: AugmentedManifestsListItemTypeDef = {...}
     ```
 """
 import sys
@@ -27,6 +27,7 @@ else:
 
 
 __all__ = (
+    "AugmentedManifestsListItemTypeDef",
     "BatchDetectDominantLanguageItemResultTypeDef",
     "BatchDetectEntitiesItemResultTypeDef",
     "BatchDetectKeyPhrasesItemResultTypeDef",
@@ -132,6 +133,10 @@ __all__ = (
     "TopicsDetectionJobFilterTypeDef",
 )
 
+AugmentedManifestsListItemTypeDef = TypedDict(
+    "AugmentedManifestsListItemTypeDef", {"S3Uri": str, "AttributeNames": List[str]}
+)
+
 BatchDetectDominantLanguageItemResultTypeDef = TypedDict(
     "BatchDetectDominantLanguageItemResultTypeDef",
     {"Index": int, "Languages": List["DominantLanguageTypeDef"]},
@@ -219,20 +224,16 @@ DocumentClassificationJobPropertiesTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredDocumentClassifierInputDataConfigTypeDef = TypedDict(
-    "_RequiredDocumentClassifierInputDataConfigTypeDef", {"S3Uri": str}
+DocumentClassifierInputDataConfigTypeDef = TypedDict(
+    "DocumentClassifierInputDataConfigTypeDef",
+    {
+        "DataFormat": Literal["COMPREHEND_CSV", "AUGMENTED_MANIFEST"],
+        "S3Uri": str,
+        "LabelDelimiter": str,
+        "AugmentedManifests": List["AugmentedManifestsListItemTypeDef"],
+    },
+    total=False,
 )
-_OptionalDocumentClassifierInputDataConfigTypeDef = TypedDict(
-    "_OptionalDocumentClassifierInputDataConfigTypeDef", {"LabelDelimiter": str}, total=False
-)
-
-
-class DocumentClassifierInputDataConfigTypeDef(
-    _RequiredDocumentClassifierInputDataConfigTypeDef,
-    _OptionalDocumentClassifierInputDataConfigTypeDef,
-):
-    pass
-
 
 DocumentClassifierOutputDataConfigTypeDef = TypedDict(
     "DocumentClassifierOutputDataConfigTypeDef", {"S3Uri": str, "KmsKeyId": str}, total=False
@@ -343,16 +344,16 @@ EntityRecognizerEvaluationMetricsTypeDef = TypedDict(
 
 _RequiredEntityRecognizerInputDataConfigTypeDef = TypedDict(
     "_RequiredEntityRecognizerInputDataConfigTypeDef",
-    {
-        "EntityTypes": List["EntityTypesListItemTypeDef"],
-        "Documents": "EntityRecognizerDocumentsTypeDef",
-    },
+    {"EntityTypes": List["EntityTypesListItemTypeDef"]},
 )
 _OptionalEntityRecognizerInputDataConfigTypeDef = TypedDict(
     "_OptionalEntityRecognizerInputDataConfigTypeDef",
     {
+        "DataFormat": Literal["COMPREHEND_CSV", "AUGMENTED_MANIFEST"],
+        "Documents": "EntityRecognizerDocumentsTypeDef",
         "Annotations": "EntityRecognizerAnnotationsTypeDef",
         "EntityList": "EntityRecognizerEntityListTypeDef",
+        "AugmentedManifests": List["AugmentedManifestsListItemTypeDef"],
     },
     total=False,
 )
